@@ -3,7 +3,7 @@ BEGIN {
   $File::Serialize::AUTHORITY = 'cpan:YANICK';
 }
 # ABSTRACT: DWIM file serialization/deserialization
-$File::Serialize::VERSION = '0.4.1';
+$File::Serialize::VERSION = '0.5.0';
 use 5.16.0;
 
 use feature 'current_sub';
@@ -48,6 +48,12 @@ our %serializers = (
         serialize   => sub { TOML::to_toml( shift ) },
         deserialize => sub { TOML::from_toml( shift ) },
     },
+    XML => {
+        extensions => [ 'xml' ],
+        init => 'XML::Simple',
+        serialize => sub { XML::Simple->new->XMLout(shift) },
+        deserialize => sub { XML::Simple->new->XMLin(shift) },
+    },
 );
 
 sub _generate_serialize_file {
@@ -137,6 +143,12 @@ sub _generate_transerialize_file {
                     $serialize_file->($f,$data,$o);
                 }
             }
+            elsif ( ref $step eq 'SCALAR' ) {
+                $$step = $data;
+            }
+            else {
+                die "wrong chain argument";
+            }
         }
 
     }
@@ -177,7 +189,7 @@ File::Serialize - DWIM file serialization/deserialization
 
 =head1 VERSION
 
-version 0.4.1
+version 0.5.0
 
 =head1 SYNOPSIS
 
@@ -264,6 +276,24 @@ None
 
 =back
 
+=head2 XML
+
+=over
+
+=item extensions
+
+xml 
+
+=item module used
+
+L<XML::Simple>
+
+=item supported options
+
+None
+
+=back
+
 =head1 OPTIONS
 
 I<File::Serialize> recognizes a set of options that, if applicable,
@@ -403,6 +433,11 @@ Has to be the final step(s) of the chain. Just like the arguments
 of C<serialize_file>. C<$filename> can be a string or a L<Path::Tiny> object.
 C<$options> is optional.
 
+=item \$result
+
+Has to be the final step of the chain. Will assign the transformed data
+to C<$result> instead of serializing to a file.
+
 =back
 
 =head1 ADDING A SERIALIZER
